/****************************************************************************
** Meta object code from reading C++ file 'stellarsolver.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../stellarsolver/stellarsolver/stellarsolver.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'stellarsolver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13StellarSolverE_t {};
} // unnamed namespace

template <> constexpr inline auto StellarSolver::qt_create_metaobjectdata<qt_meta_tag_ZN13StellarSolverE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StellarSolver",
        "logOutput",
        "",
        "logText",
        "ready",
        "finished",
        "processFinished",
        "code",
        "finishParallelSolve",
        "success",
        "BasePath",
        "FileToProcess",
        "AstrometryAPIKey",
        "AstrometryAPIURL",
        "LogFileName",
        "UsePosition",
        "UseScale",
        "AutoGenerateAstroConfig",
        "CleanupTemporaryFiles",
        "OnlySendFITSFiles",
        "LogToFile",
        "SolverType",
        "ProcessType",
        "ExtractorType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'logOutput'
        QtMocHelpers::SignalData<void(QString)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processFinished'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'finishParallelSolve'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'BasePath'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'FileToProcess'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'AstrometryAPIKey'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'AstrometryAPIURL'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'LogFileName'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'UsePosition'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'UseScale'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'AutoGenerateAstroConfig'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'CleanupTemporaryFiles'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'OnlySendFITSFiles'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'LogToFile'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'SolverType'
        QtMocHelpers::PropertyData<SolverType>(21, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'ProcessType'
        QtMocHelpers::PropertyData<ProcessType>(22, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
        // property 'ExtractorType'
        QtMocHelpers::PropertyData<ExtractorType>(23, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StellarSolver, qt_meta_tag_ZN13StellarSolverE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StellarSolver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13StellarSolverE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13StellarSolverE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13StellarSolverE_t>.metaTypes,
    nullptr
} };

void StellarSolver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StellarSolver *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->logOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->ready(); break;
        case 2: _t->finished(); break;
        case 3: _t->processFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->finishParallelSolve((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (StellarSolver::*)(QString )>(_a, &StellarSolver::logOutput, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (StellarSolver::*)()>(_a, &StellarSolver::ready, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (StellarSolver::*)()>(_a, &StellarSolver::finished, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_BasePath; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_FileToProcess; break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->m_AstrometryAPIKey; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->m_AstrometryAPIURL; break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->m_LogFileName; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_UsePosition; break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->m_UseScale; break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->m_AutoGenerateAstroConfig; break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->m_CleanupTemporaryFiles; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->m_OnlySendFITSFiles; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->m_LogToFile; break;
        case 11: *reinterpret_cast<SolverType*>(_v) = _t->m_SolverType; break;
        case 12: *reinterpret_cast<ProcessType*>(_v) = _t->m_ProcessType; break;
        case 13: *reinterpret_cast<ExtractorType*>(_v) = _t->m_ExtractorType; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_BasePath, *reinterpret_cast<QString*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_FileToProcess, *reinterpret_cast<QString*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_AstrometryAPIKey, *reinterpret_cast<QString*>(_v)); break;
        case 3: QtMocHelpers::setProperty(_t->m_AstrometryAPIURL, *reinterpret_cast<QString*>(_v)); break;
        case 4: QtMocHelpers::setProperty(_t->m_LogFileName, *reinterpret_cast<QString*>(_v)); break;
        case 5: QtMocHelpers::setProperty(_t->m_UsePosition, *reinterpret_cast<bool*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_UseScale, *reinterpret_cast<bool*>(_v)); break;
        case 7: QtMocHelpers::setProperty(_t->m_AutoGenerateAstroConfig, *reinterpret_cast<bool*>(_v)); break;
        case 8: QtMocHelpers::setProperty(_t->m_CleanupTemporaryFiles, *reinterpret_cast<bool*>(_v)); break;
        case 9: QtMocHelpers::setProperty(_t->m_OnlySendFITSFiles, *reinterpret_cast<bool*>(_v)); break;
        case 10: QtMocHelpers::setProperty(_t->m_LogToFile, *reinterpret_cast<bool*>(_v)); break;
        case 11: QtMocHelpers::setProperty(_t->m_SolverType, *reinterpret_cast<SolverType*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->m_ProcessType, *reinterpret_cast<ProcessType*>(_v)); break;
        case 13: QtMocHelpers::setProperty(_t->m_ExtractorType, *reinterpret_cast<ExtractorType*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *StellarSolver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StellarSolver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13StellarSolverE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int StellarSolver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void StellarSolver::logOutput(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void StellarSolver::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void StellarSolver::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
