// This file is autogenerated. Changes will be overwritten.
#include "FJZUQTFNOB/moc_astrometrylogger.cpp"
#include "FJZUQTFNOB/moc_externalextractorsolver.cpp"
#include "FJZUQTFNOB/moc_extractorsolver.cpp"
#include "FJZUQTFNOB/moc_onlinesolver.cpp"
#include "FJZUQTFNOB/moc_stellarsolver.cpp"
