/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../stellarsolver/tester/mainwindow.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "readyForStarTable",
        "",
        "prepareForProcesses",
        "logOutput",
        "text",
        "toggleLogDisplay",
        "toggleFullScreen",
        "helpPopup",
        "startProcessMonitor",
        "stopProcessMonitor",
        "clearStars",
        "clearResults",
        "loadOptionsProfile",
        "settingJustChanged",
        "loadIndexFilesListInFolder",
        "loadIndexFilesToUse",
        "setSubframe",
        "extractButtonClicked",
        "solveButtonClicked",
        "extractImage",
        "solveImage",
        "abort",
        "imageLoad",
        "imageSave",
        "clearImageBuffers",
        "zoomIn",
        "zoomOut",
        "panLeft",
        "panRight",
        "panUp",
        "panDown",
        "autoScale",
        "updateImage",
        "displayTable",
        "sortStars",
        "starClickedInTable",
        "updateStarTableFromList",
        "updateHiddenStarTableColumns",
        "saveStarTable",
        "mouseMovedOverImage",
        "QPoint",
        "location",
        "getValue",
        "x",
        "y",
        "channel",
        "mouseClickedInImage",
        "mousePressedInImage",
        "getStarSizeInImage",
        "QRect",
        "FITSImage::Star",
        "star",
        "bool&",
        "accurate",
        "reloadConvTable",
        "getSettingsFromUI",
        "SSolver::Parameters",
        "sendSettingsToUI",
        "a",
        "setupExternalExtractorSolverIfNeeded",
        "setupStellarSolverParameters",
        "extractorComplete",
        "solverComplete",
        "addSolutionToTable",
        "FITSImage::Solution",
        "solution",
        "updateHiddenResultsTableColumns",
        "saveResultsTable",
        "saveOptionsProfiles",
        "loadOptionsProfiles",
        "closeEvent",
        "QCloseEvent*",
        "event"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'readyForStarTable'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prepareForProcesses'
        QtMocHelpers::SlotData<bool()>(3, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'logOutput'
        QtMocHelpers::SlotData<void(QString)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'toggleLogDisplay'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleFullScreen'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'helpPopup'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startProcessMonitor'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopProcessMonitor'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearStars'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearResults'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadOptionsProfile'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'settingJustChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadIndexFilesListInFolder'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadIndexFilesToUse'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setSubframe'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractButtonClicked'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'solveButtonClicked'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractImage'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'solveImage'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'abort'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'imageLoad'
        QtMocHelpers::SlotData<bool()>(23, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'imageSave'
        QtMocHelpers::SlotData<bool()>(24, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'clearImageBuffers'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'panLeft'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'panRight'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'panUp'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'panDown'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'autoScale'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateImage'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'displayTable'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sortStars'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'starClickedInTable'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateStarTableFromList'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateHiddenStarTableColumns'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveStarTable'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'mouseMovedOverImage'
        QtMocHelpers::SlotData<void(QPoint)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'getValue'
        QtMocHelpers::SlotData<QString(int, int, int)>(43, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 44 }, { QMetaType::Int, 45 }, { QMetaType::Int, 46 },
        }}),
        // Slot 'mouseClickedInImage'
        QtMocHelpers::SlotData<void(QPoint)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'mousePressedInImage'
        QtMocHelpers::SlotData<void(QPoint)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'getStarSizeInImage'
        QtMocHelpers::SlotData<QRect(FITSImage::Star, bool &)>(49, 2, QMC::AccessPublic, 0x80000000 | 50, {{
            { 0x80000000 | 51, 52 }, { 0x80000000 | 53, 54 },
        }}),
        // Slot 'reloadConvTable'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getSettingsFromUI'
        QtMocHelpers::SlotData<SSolver::Parameters()>(56, 2, QMC::AccessPublic, 0x80000000 | 57),
        // Slot 'sendSettingsToUI'
        QtMocHelpers::SlotData<void(SSolver::Parameters)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 57, 59 },
        }}),
        // Slot 'setupExternalExtractorSolverIfNeeded'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setupStellarSolverParameters'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractorComplete'
        QtMocHelpers::SlotData<bool()>(62, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'solverComplete'
        QtMocHelpers::SlotData<bool()>(63, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'addSolutionToTable'
        QtMocHelpers::SlotData<void(FITSImage::Solution)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 66 },
        }}),
        // Slot 'updateHiddenResultsTableColumns'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveResultsTable'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'saveOptionsProfiles'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadOptionsProfiles'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'closeEvent'
        QtMocHelpers::SlotData<void(QCloseEvent *)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 72, 73 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->readyForStarTable(); break;
        case 1: { bool _r = _t->prepareForProcesses();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->logOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->toggleLogDisplay(); break;
        case 4: _t->toggleFullScreen(); break;
        case 5: _t->helpPopup(); break;
        case 6: _t->startProcessMonitor(); break;
        case 7: _t->stopProcessMonitor(); break;
        case 8: _t->clearStars(); break;
        case 9: _t->clearResults(); break;
        case 10: _t->loadOptionsProfile(); break;
        case 11: _t->settingJustChanged(); break;
        case 12: _t->loadIndexFilesListInFolder(); break;
        case 13: _t->loadIndexFilesToUse(); break;
        case 14: _t->setSubframe(); break;
        case 15: _t->extractButtonClicked(); break;
        case 16: _t->solveButtonClicked(); break;
        case 17: _t->extractImage(); break;
        case 18: _t->solveImage(); break;
        case 19: _t->abort(); break;
        case 20: { bool _r = _t->imageLoad();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->imageSave();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->clearImageBuffers(); break;
        case 23: _t->zoomIn(); break;
        case 24: _t->zoomOut(); break;
        case 25: _t->panLeft(); break;
        case 26: _t->panRight(); break;
        case 27: _t->panUp(); break;
        case 28: _t->panDown(); break;
        case 29: _t->autoScale(); break;
        case 30: _t->updateImage(); break;
        case 31: _t->displayTable(); break;
        case 32: _t->sortStars(); break;
        case 33: _t->starClickedInTable(); break;
        case 34: _t->updateStarTableFromList(); break;
        case 35: _t->updateHiddenStarTableColumns(); break;
        case 36: _t->saveStarTable(); break;
        case 37: _t->mouseMovedOverImage((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 38: { QString _r = _t->getValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 39: _t->mouseClickedInImage((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 40: _t->mousePressedInImage((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 41: { QRect _r = _t->getStarSizeInImage((*reinterpret_cast<std::add_pointer_t<FITSImage::Star>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QRect*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->reloadConvTable(); break;
        case 43: { SSolver::Parameters _r = _t->getSettingsFromUI();
            if (_a[0]) *reinterpret_cast<SSolver::Parameters*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->sendSettingsToUI((*reinterpret_cast<std::add_pointer_t<SSolver::Parameters>>(_a[1]))); break;
        case 45: _t->setupExternalExtractorSolverIfNeeded(); break;
        case 46: _t->setupStellarSolverParameters(); break;
        case 47: { bool _r = _t->extractorComplete();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { bool _r = _t->solverComplete();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->addSolutionToTable((*reinterpret_cast<std::add_pointer_t<FITSImage::Solution>>(_a[1]))); break;
        case 50: _t->updateHiddenResultsTableColumns(); break;
        case 51: _t->saveResultsTable(); break;
        case 52: _t->saveOptionsProfiles(); break;
        case 53: _t->loadOptionsProfiles(); break;
        case 54: _t->closeEvent((*reinterpret_cast<std::add_pointer_t<QCloseEvent*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::readyForStarTable, 0))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 55)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 55;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 55)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 55;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::readyForStarTable()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
