/********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStatusBar>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <ssolverutils/imagelabel.h>

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_2;
    QPushButton *ImageLoad;
    QPushButton *ImageSave;
    QPushButton *zoomIn;
    QPushButton *zoomOut;
    QPushButton *AutoScale;
    QSplitter *horSplitter;
    QWidget *widget;
    QVBoxLayout *verticalLayout_4;
    QTabWidget *optionsTab;
    QWidget *tab_3;
    QGridLayout *gridLayout_9;
    QToolBox *toolBox;
    QWidget *page;
    QGridLayout *gridLayout_15;
    QLabel *label_47;
    QWidget *page_5;
    QGridLayout *gridLayout_12;
    QLabel *label_34;
    QSpacerItem *verticalSpacer_2;
    QCheckBox *logToFile;
    QLabel *label_59;
    QComboBox *stellarSolverLogLevel;
    QComboBox *logLevel;
    QLineEdit *logFileName;
    QLabel *label_61;
    QWidget *page_2;
    QGridLayout *gridLayout_13;
    QLineEdit *configFilePath;
    QLabel *label_11;
    QLineEdit *basePath;
    QPushButton *openTemp;
    QLineEdit *apiKey;
    QLabel *label_3;
    QLabel *label_42;
    QLabel *label;
    QLineEdit *astapPath;
    QLabel *label_63;
    QLineEdit *solverPath;
    QLabel *label_2;
    QLineEdit *sextractorPath;
    QLineEdit *onlineServer;
    QSpacerItem *verticalSpacer;
    QCheckBox *generateAstrometryConfig;
    QLabel *label_45;
    QLineEdit *wcsPath;
    QLabel *label_10;
    QLabel *label_64;
    QLineEdit *watneyPath;
    QCheckBox *cleanupTemp;
    QLabel *label_62;
    QComboBox *setPathsAutomatically;
    QWidget *page_4;
    QGridLayout *gridLayout_3;
    QLineEdit *scale_high;
    QLabel *label_6;
    QLineEdit *scale_low;
    QCheckBox *use_position;
    QLabel *label_7;
    QLineEdit *dec;
    QComboBox *units;
    QLineEdit *deString;
    QLabel *label_31;
    QLineEdit *raString;
    QLabel *label_4;
    QLabel *label_5;
    QLineEdit *ra;
    QCheckBox *use_scale;
    QLabel *label_8;
    QCheckBox *autoUpdateScaleAndPosition;
    QWidget *page_3;
    QGridLayout *gridLayout_10;
    QPushButton *removeIndexPath;
    QListWidget *indexFiles;
    QListWidget *indexFilesToUse;
    QComboBox *useAllIndexes;
    QComboBox *indexFolderPaths;
    QLabel *label_66;
    QPushButton *addIndexPath;
    QLabel *label_26;
    QLabel *label_30;
    QLineEdit *singleIndexNum;
    QLineEdit *singleHealpix;
    QWidget *tab_4;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QPushButton *loadSettings;
    QPushButton *saveSettings;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *optionsProfile;
    QPushButton *addOptionProfile;
    QPushButton *removeOptionProfile;
    QTextEdit *description;
    QToolBox *optionsBox;
    QWidget *Sextractor;
    QGridLayout *gridLayout_8;
    QLineEdit *thresh_multiple;
    QCheckBox *partition;
    QPushButton *showConv;
    QLineEdit *deblend_contrast;
    QLabel *label_20;
    QLabel *label_14;
    QLabel *label_t1;
    QLineEdit *deblend_thresh;
    QLabel *label_12;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_23;
    QLabel *label_18;
    QLineEdit *kron_fact;
    QLabel *label_25;
    QLineEdit *magzero;
    QCheckBox *cleanCheckBox;
    QLabel *label_24;
    QLabel *label_t2;
    QComboBox *apertureShape;
    QLabel *label_19;
    QLineEdit *r_min;
    QLabel *label_13;
    QLineEdit *thresh_offset;
    QSpinBox *fwhm;
    QLineEdit *clean_param;
    QLineEdit *minarea;
    QLineEdit *subpix;
    QLabel *label_21;
    QLabel *label_38;
    QLabel *label_15;
    QLabel *label_65;
    QComboBox *convFilterType;
    QWidget *StarFilters;
    QGridLayout *gridLayout_11;
    QLineEdit *dimmestPercent;
    QLabel *label_48;
    QSpacerItem *verticalSpacer_3;
    QCheckBox *resortQT;
    QLineEdit *maxEllipse;
    QLabel *label_54;
    QLabel *label_55;
    QLabel *label_52;
    QLineEdit *saturationLimit;
    QLabel *label_39;
    QLabel *label_56;
    QLineEdit *maxSize;
    QLabel *label_43;
    QLabel *label_40;
    QLineEdit *keepNum;
    QLabel *label_57;
    QLabel *label_51;
    QLabel *label_41;
    QLabel *label_49;
    QLineEdit *minSize;
    QLabel *label_46;
    QLineEdit *brightestPercent;
    QLabel *label_53;
    QLabel *label_44;
    QLineEdit *initialKeep;
    QLabel *label_58;
    QLabel *label_60;
    QWidget *Astrometry;
    QGridLayout *gridLayout_4;
    QScrollArea *scrollArea_3;
    QWidget *scrollAreaWidgetContents_3;
    QGridLayout *gridLayout_5;
    QLineEdit *solverTimeLimit;
    QLineEdit *radius;
    QLabel *label_9;
    QLabel *label_36;
    QLineEdit *minWidth;
    QLabel *label_37;
    QLabel *label_33;
    QCheckBox *inParallel;
    QLabel *label_28;
    QLineEdit *oddsToTune;
    QLabel *label_29;
    QSpacerItem *verticalSpacer_7;
    QLabel *label_27;
    QLineEdit *oddsToSolve;
    QLineEdit *maxWidth;
    QComboBox *multiAlgo;
    QLineEdit *oddsToKeep;
    QLabel *label_16;
    QLabel *label_35;
    QSpinBox *downsample;
    QCheckBox *resort;
    QCheckBox *autoDown;
    QWidget *widget_3;
    QVBoxLayout *verticalLayout_6;
    QSplitter *vertSplitter;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout_2;
    QLabel *fileNameDisplay;
    QScrollArea *imageScrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_2;
    ImageLabel *Image;
    QHBoxLayout *horizontalLayout_8;
    QLabel *mouseInfo;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *setSubFrame;
    QCheckBox *showStars;
    QComboBox *starOptions;
    QComboBox *channelSelection;
    QTabWidget *tabWidget;
    QWidget *logOutput;
    QGridLayout *gridLayout_6;
    QPlainTextEdit *logDisplay;
    QWidget *resultsTableView;
    QGridLayout *gridLayout_7;
    QTableWidget *resultsTable;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *showExtractorParams;
    QCheckBox *showAstrometryParams;
    QCheckBox *showSolutionDetails;
    QSpacerItem *horizontalSpacer;
    QFrame *frame;
    QVBoxLayout *verticalLayout_5;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_50;
    QCheckBox *showFluxInfo;
    QCheckBox *showStarShapeInfo;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_9;
    QPushButton *ClearStars;
    QPushButton *exportStarTable;
    QTableWidget *starTable;
    QGridLayout *gridLayout_14;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_18;
    QComboBox *extractionProfile;
    QPushButton *editExtractorProfile;
    QPushButton *startExtraction;
    QComboBox *extractorTypeForExtraction;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_17;
    QComboBox *solverProfile;
    QComboBox *extractorTypeForSolving;
    QComboBox *solverType;
    QPushButton *startSolving;
    QPushButton *editSolverProfile;
    QPushButton *ClearResults;
    QPushButton *Abort;
    QLabel *label_32;
    QSpinBox *trials;
    QPushButton *exportResultsTable;
    QHBoxLayout *horizontalLayout_6;
    QLabel *status;
    QProgressBar *progressBar;
    QStatusBar *statusbar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName("MainWindow");
        MainWindow->resize(1198, 808);
        QFont font;
        font.setKerning(true);
        MainWindow->setFont(font);
        centralwidget = new QWidget(MainWindow);
        centralwidget->setObjectName("centralwidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(centralwidget->sizePolicy().hasHeightForWidth());
        centralwidget->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(centralwidget);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, 0, -1, -1);
        ImageLoad = new QPushButton(centralwidget);
        ImageLoad->setObjectName("ImageLoad");

        horizontalLayout_2->addWidget(ImageLoad);

        ImageSave = new QPushButton(centralwidget);
        ImageSave->setObjectName("ImageSave");

        horizontalLayout_2->addWidget(ImageSave);

        zoomIn = new QPushButton(centralwidget);
        zoomIn->setObjectName("zoomIn");

        horizontalLayout_2->addWidget(zoomIn);

        zoomOut = new QPushButton(centralwidget);
        zoomOut->setObjectName("zoomOut");

        horizontalLayout_2->addWidget(zoomOut);

        AutoScale = new QPushButton(centralwidget);
        AutoScale->setObjectName("AutoScale");

        horizontalLayout_2->addWidget(AutoScale);


        verticalLayout->addLayout(horizontalLayout_2);

        horSplitter = new QSplitter(centralwidget);
        horSplitter->setObjectName("horSplitter");
        horSplitter->setOrientation(Qt::Horizontal);
        horSplitter->setHandleWidth(15);
        widget = new QWidget(horSplitter);
        widget->setObjectName("widget");
        verticalLayout_4 = new QVBoxLayout(widget);
        verticalLayout_4->setSpacing(0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        optionsTab = new QTabWidget(widget);
        optionsTab->setObjectName("optionsTab");
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_9 = new QGridLayout(tab_3);
        gridLayout_9->setObjectName("gridLayout_9");
        toolBox = new QToolBox(tab_3);
        toolBox->setObjectName("toolBox");
        page = new QWidget();
        page->setObjectName("page");
        page->setGeometry(QRect(0, 0, 298, 416));
        gridLayout_15 = new QGridLayout(page);
        gridLayout_15->setObjectName("gridLayout_15");
        label_47 = new QLabel(page);
        label_47->setObjectName("label_47");
        label_47->setMinimumSize(QSize(0, 0));
        label_47->setWordWrap(true);
        label_47->setOpenExternalLinks(true);

        gridLayout_15->addWidget(label_47, 0, 0, 1, 1);

        toolBox->addItem(page, QString::fromUtf8("StellarSolver"));
        page_5 = new QWidget();
        page_5->setObjectName("page_5");
        page_5->setGeometry(QRect(0, 0, 298, 416));
        gridLayout_12 = new QGridLayout(page_5);
        gridLayout_12->setObjectName("gridLayout_12");
        label_34 = new QLabel(page_5);
        label_34->setObjectName("label_34");

        gridLayout_12->addWidget(label_34, 5, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_12->addItem(verticalSpacer_2, 20, 0, 1, 1);

        logToFile = new QCheckBox(page_5);
        logToFile->setObjectName("logToFile");

        gridLayout_12->addWidget(logToFile, 0, 0, 1, 2);

        label_59 = new QLabel(page_5);
        label_59->setObjectName("label_59");

        gridLayout_12->addWidget(label_59, 4, 0, 1, 1);

        stellarSolverLogLevel = new QComboBox(page_5);
        stellarSolverLogLevel->addItem(QString());
        stellarSolverLogLevel->addItem(QString());
        stellarSolverLogLevel->addItem(QString());
        stellarSolverLogLevel->setObjectName("stellarSolverLogLevel");

        gridLayout_12->addWidget(stellarSolverLogLevel, 4, 1, 1, 1);

        logLevel = new QComboBox(page_5);
        logLevel->addItem(QString());
        logLevel->addItem(QString());
        logLevel->addItem(QString());
        logLevel->addItem(QString());
        logLevel->addItem(QString());
        logLevel->setObjectName("logLevel");

        gridLayout_12->addWidget(logLevel, 5, 1, 1, 1);

        logFileName = new QLineEdit(page_5);
        logFileName->setObjectName("logFileName");

        gridLayout_12->addWidget(logFileName, 1, 1, 1, 1);

        label_61 = new QLabel(page_5);
        label_61->setObjectName("label_61");

        gridLayout_12->addWidget(label_61, 1, 0, 1, 1);

        toolBox->addItem(page_5, QString::fromUtf8("Logging"));
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        page_2->setGeometry(QRect(0, 0, 289, 426));
        gridLayout_13 = new QGridLayout(page_2);
        gridLayout_13->setObjectName("gridLayout_13");
        configFilePath = new QLineEdit(page_2);
        configFilePath->setObjectName("configFilePath");

        gridLayout_13->addWidget(configFilePath, 7, 2, 1, 1);

        label_11 = new QLabel(page_2);
        label_11->setObjectName("label_11");

        gridLayout_13->addWidget(label_11, 3, 1, 1, 1);

        basePath = new QLineEdit(page_2);
        basePath->setObjectName("basePath");

        gridLayout_13->addWidget(basePath, 3, 2, 1, 1);

        openTemp = new QPushButton(page_2);
        openTemp->setObjectName("openTemp");

        gridLayout_13->addWidget(openTemp, 4, 1, 1, 2);

        apiKey = new QLineEdit(page_2);
        apiKey->setObjectName("apiKey");

        gridLayout_13->addWidget(apiKey, 18, 2, 1, 1);

        label_3 = new QLabel(page_2);
        label_3->setObjectName("label_3");

        gridLayout_13->addWidget(label_3, 7, 1, 1, 1);

        label_42 = new QLabel(page_2);
        label_42->setObjectName("label_42");

        gridLayout_13->addWidget(label_42, 13, 1, 1, 1);

        label = new QLabel(page_2);
        label->setObjectName("label");
        label->setOpenExternalLinks(true);

        gridLayout_13->addWidget(label, 0, 1, 1, 1);

        astapPath = new QLineEdit(page_2);
        astapPath->setObjectName("astapPath");

        gridLayout_13->addWidget(astapPath, 1, 2, 1, 1);

        label_63 = new QLabel(page_2);
        label_63->setObjectName("label_63");

        gridLayout_13->addWidget(label_63, 17, 1, 1, 1);

        solverPath = new QLineEdit(page_2);
        solverPath->setObjectName("solverPath");

        gridLayout_13->addWidget(solverPath, 9, 2, 1, 1);

        label_2 = new QLabel(page_2);
        label_2->setObjectName("label_2");

        gridLayout_13->addWidget(label_2, 9, 1, 1, 1);

        sextractorPath = new QLineEdit(page_2);
        sextractorPath->setObjectName("sextractorPath");

        gridLayout_13->addWidget(sextractorPath, 0, 2, 1, 1);

        onlineServer = new QLineEdit(page_2);
        onlineServer->setObjectName("onlineServer");

        gridLayout_13->addWidget(onlineServer, 17, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_13->addItem(verticalSpacer, 19, 1, 1, 1);

        generateAstrometryConfig = new QCheckBox(page_2);
        generateAstrometryConfig->setObjectName("generateAstrometryConfig");
        generateAstrometryConfig->setChecked(true);

        gridLayout_13->addWidget(generateAstrometryConfig, 15, 1, 1, 2);

        label_45 = new QLabel(page_2);
        label_45->setObjectName("label_45");
        label_45->setOpenExternalLinks(true);

        gridLayout_13->addWidget(label_45, 1, 1, 1, 1);

        wcsPath = new QLineEdit(page_2);
        wcsPath->setObjectName("wcsPath");

        gridLayout_13->addWidget(wcsPath, 13, 2, 1, 1);

        label_10 = new QLabel(page_2);
        label_10->setObjectName("label_10");
        label_10->setOpenExternalLinks(true);

        gridLayout_13->addWidget(label_10, 5, 1, 1, 2);

        label_64 = new QLabel(page_2);
        label_64->setObjectName("label_64");
        label_64->setOpenExternalLinks(true);

        gridLayout_13->addWidget(label_64, 2, 1, 1, 1);

        watneyPath = new QLineEdit(page_2);
        watneyPath->setObjectName("watneyPath");

        gridLayout_13->addWidget(watneyPath, 2, 2, 1, 1);

        cleanupTemp = new QCheckBox(page_2);
        cleanupTemp->setObjectName("cleanupTemp");
        cleanupTemp->setChecked(true);

        gridLayout_13->addWidget(cleanupTemp, 14, 1, 1, 2);

        label_62 = new QLabel(page_2);
        label_62->setObjectName("label_62");

        gridLayout_13->addWidget(label_62, 18, 1, 1, 1);

        setPathsAutomatically = new QComboBox(page_2);
        setPathsAutomatically->addItem(QString());
        setPathsAutomatically->addItem(QString());
        setPathsAutomatically->addItem(QString());
        setPathsAutomatically->addItem(QString());
        setPathsAutomatically->addItem(QString());
        setPathsAutomatically->setObjectName("setPathsAutomatically");

        gridLayout_13->addWidget(setPathsAutomatically, 16, 1, 1, 2);

        toolBox->addItem(page_2, QString::fromUtf8("Online/External Program Options"));
        page_4 = new QWidget();
        page_4->setObjectName("page_4");
        page_4->setGeometry(QRect(0, 0, 298, 416));
        gridLayout_3 = new QGridLayout(page_4);
        gridLayout_3->setObjectName("gridLayout_3");
        scale_high = new QLineEdit(page_4);
        scale_high->setObjectName("scale_high");

        gridLayout_3->addWidget(scale_high, 2, 2, 1, 1);

        label_6 = new QLabel(page_4);
        label_6->setObjectName("label_6");

        gridLayout_3->addWidget(label_6, 3, 1, 1, 1);

        scale_low = new QLineEdit(page_4);
        scale_low->setObjectName("scale_low");

        gridLayout_3->addWidget(scale_low, 1, 2, 1, 1);

        use_position = new QCheckBox(page_4);
        use_position->setObjectName("use_position");

        gridLayout_3->addWidget(use_position, 4, 1, 1, 2);

        label_7 = new QLabel(page_4);
        label_7->setObjectName("label_7");

        gridLayout_3->addWidget(label_7, 5, 1, 1, 1);

        dec = new QLineEdit(page_4);
        dec->setObjectName("dec");

        gridLayout_3->addWidget(dec, 7, 2, 1, 1);

        units = new QComboBox(page_4);
        units->addItem(QString());
        units->addItem(QString());
        units->addItem(QString());
        units->addItem(QString());
        units->setObjectName("units");

        gridLayout_3->addWidget(units, 3, 2, 1, 1);

        deString = new QLineEdit(page_4);
        deString->setObjectName("deString");
        QPalette palette;
        QBrush brush(QColor(255, 255, 255, 216));
        brush.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        QBrush brush1(QColor(129, 129, 129, 217));
        brush1.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush1);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        QBrush brush2(QColor(255, 255, 255, 63));
        brush2.setStyle(Qt::BrushStyle::SolidPattern);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush2);
        palette.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush2);
        deString->setPalette(palette);
        deString->setReadOnly(true);

        gridLayout_3->addWidget(deString, 8, 2, 1, 1);

        label_31 = new QLabel(page_4);
        label_31->setObjectName("label_31");
        label_31->setWordWrap(true);

        gridLayout_3->addWidget(label_31, 10, 1, 1, 2);

        raString = new QLineEdit(page_4);
        raString->setObjectName("raString");
        QPalette palette1;
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::WindowText, brush);
        palette1.setBrush(QPalette::ColorGroup::Active, QPalette::ColorRole::Text, brush1);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::WindowText, brush);
        palette1.setBrush(QPalette::ColorGroup::Inactive, QPalette::ColorRole::Text, brush);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::WindowText, brush2);
        palette1.setBrush(QPalette::ColorGroup::Disabled, QPalette::ColorRole::Text, brush2);
        raString->setPalette(palette1);
        raString->setReadOnly(true);

        gridLayout_3->addWidget(raString, 6, 2, 1, 1);

        label_4 = new QLabel(page_4);
        label_4->setObjectName("label_4");

        gridLayout_3->addWidget(label_4, 1, 1, 1, 1);

        label_5 = new QLabel(page_4);
        label_5->setObjectName("label_5");

        gridLayout_3->addWidget(label_5, 2, 1, 1, 1);

        ra = new QLineEdit(page_4);
        ra->setObjectName("ra");

        gridLayout_3->addWidget(ra, 5, 2, 1, 1);

        use_scale = new QCheckBox(page_4);
        use_scale->setObjectName("use_scale");

        gridLayout_3->addWidget(use_scale, 0, 1, 1, 2);

        label_8 = new QLabel(page_4);
        label_8->setObjectName("label_8");

        gridLayout_3->addWidget(label_8, 7, 1, 1, 1);

        autoUpdateScaleAndPosition = new QCheckBox(page_4);
        autoUpdateScaleAndPosition->setObjectName("autoUpdateScaleAndPosition");

        gridLayout_3->addWidget(autoUpdateScaleAndPosition, 9, 1, 1, 2);

        toolBox->addItem(page_4, QString::fromUtf8("Scale/Position"));
        page_3 = new QWidget();
        page_3->setObjectName("page_3");
        page_3->setGeometry(QRect(0, 0, 290, 564));
        gridLayout_10 = new QGridLayout(page_3);
        gridLayout_10->setObjectName("gridLayout_10");
        removeIndexPath = new QPushButton(page_3);
        removeIndexPath->setObjectName("removeIndexPath");

        gridLayout_10->addWidget(removeIndexPath, 0, 3, 1, 1);

        indexFiles = new QListWidget(page_3);
        indexFiles->setObjectName("indexFiles");

        gridLayout_10->addWidget(indexFiles, 4, 1, 1, 4);

        indexFilesToUse = new QListWidget(page_3);
        indexFilesToUse->setObjectName("indexFilesToUse");

        gridLayout_10->addWidget(indexFilesToUse, 7, 1, 1, 4);

        useAllIndexes = new QComboBox(page_3);
        useAllIndexes->addItem(QString());
        useAllIndexes->addItem(QString());
        useAllIndexes->addItem(QString());
        useAllIndexes->setObjectName("useAllIndexes");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(useAllIndexes->sizePolicy().hasHeightForWidth());
        useAllIndexes->setSizePolicy(sizePolicy1);
        useAllIndexes->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_10->addWidget(useAllIndexes, 5, 1, 1, 2);

        indexFolderPaths = new QComboBox(page_3);
        indexFolderPaths->setObjectName("indexFolderPaths");
        indexFolderPaths->setEditable(false);

        gridLayout_10->addWidget(indexFolderPaths, 2, 1, 1, 3);

        label_66 = new QLabel(page_3);
        label_66->setObjectName("label_66");
        label_66->setWordWrap(true);

        gridLayout_10->addWidget(label_66, 6, 1, 1, 4);

        addIndexPath = new QPushButton(page_3);
        addIndexPath->setObjectName("addIndexPath");

        gridLayout_10->addWidget(addIndexPath, 0, 1, 1, 1);

        label_26 = new QLabel(page_3);
        label_26->setObjectName("label_26");
        label_26->setWordWrap(true);

        gridLayout_10->addWidget(label_26, 1, 1, 1, 5);

        label_30 = new QLabel(page_3);
        label_30->setObjectName("label_30");
        label_30->setWordWrap(true);

        gridLayout_10->addWidget(label_30, 3, 1, 1, 5);

        singleIndexNum = new QLineEdit(page_3);
        singleIndexNum->setObjectName("singleIndexNum");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(singleIndexNum->sizePolicy().hasHeightForWidth());
        singleIndexNum->setSizePolicy(sizePolicy2);
        singleIndexNum->setMinimumSize(QSize(50, 0));
        singleIndexNum->setMaximumSize(QSize(50, 16777215));
        singleIndexNum->setReadOnly(true);

        gridLayout_10->addWidget(singleIndexNum, 5, 3, 1, 1);

        singleHealpix = new QLineEdit(page_3);
        singleHealpix->setObjectName("singleHealpix");
        sizePolicy2.setHeightForWidth(singleHealpix->sizePolicy().hasHeightForWidth());
        singleHealpix->setSizePolicy(sizePolicy2);
        singleHealpix->setMinimumSize(QSize(50, 0));
        singleHealpix->setMaximumSize(QSize(50, 16777215));
        singleHealpix->setReadOnly(true);

        gridLayout_10->addWidget(singleHealpix, 5, 4, 1, 1);

        toolBox->addItem(page_3, QString::fromUtf8("Index Files"));

        gridLayout_9->addWidget(toolBox, 0, 0, 1, 1);

        optionsTab->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout = new QGridLayout(tab_4);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(3, 3, 3, 3);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        loadSettings = new QPushButton(tab_4);
        loadSettings->setObjectName("loadSettings");

        horizontalLayout->addWidget(loadSettings);

        saveSettings = new QPushButton(tab_4);
        saveSettings->setObjectName("saveSettings");

        horizontalLayout->addWidget(saveSettings);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setSpacing(0);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        optionsProfile = new QComboBox(tab_4);
        optionsProfile->addItem(QString());
        optionsProfile->setObjectName("optionsProfile");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(optionsProfile->sizePolicy().hasHeightForWidth());
        optionsProfile->setSizePolicy(sizePolicy3);

        horizontalLayout_4->addWidget(optionsProfile);

        addOptionProfile = new QPushButton(tab_4);
        addOptionProfile->setObjectName("addOptionProfile");
        addOptionProfile->setMinimumSize(QSize(0, 0));
        addOptionProfile->setMaximumSize(QSize(30, 30));

        horizontalLayout_4->addWidget(addOptionProfile);

        removeOptionProfile = new QPushButton(tab_4);
        removeOptionProfile->setObjectName("removeOptionProfile");
        removeOptionProfile->setMaximumSize(QSize(30, 30));

        horizontalLayout_4->addWidget(removeOptionProfile);


        gridLayout->addLayout(horizontalLayout_4, 0, 0, 1, 1);

        description = new QTextEdit(tab_4);
        description->setObjectName("description");
        description->setMaximumSize(QSize(16777215, 50));

        gridLayout->addWidget(description, 2, 0, 1, 1);

        optionsBox = new QToolBox(tab_4);
        optionsBox->setObjectName("optionsBox");
        Sextractor = new QWidget();
        Sextractor->setObjectName("Sextractor");
        Sextractor->setGeometry(QRect(0, 0, 296, 533));
        gridLayout_8 = new QGridLayout(Sextractor);
        gridLayout_8->setObjectName("gridLayout_8");
        thresh_multiple = new QLineEdit(Sextractor);
        thresh_multiple->setObjectName("thresh_multiple");

        gridLayout_8->addWidget(thresh_multiple, 2, 2, 1, 1);

        partition = new QCheckBox(Sextractor);
        partition->setObjectName("partition");
        partition->setChecked(true);

        gridLayout_8->addWidget(partition, 17, 1, 1, 1);

        showConv = new QPushButton(Sextractor);
        showConv->setObjectName("showConv");

        gridLayout_8->addWidget(showConv, 16, 1, 1, 2);

        deblend_contrast = new QLineEdit(Sextractor);
        deblend_contrast->setObjectName("deblend_contrast");

        gridLayout_8->addWidget(deblend_contrast, 10, 2, 1, 1);

        label_20 = new QLabel(Sextractor);
        label_20->setObjectName("label_20");
        label_20->setOpenExternalLinks(true);

        gridLayout_8->addWidget(label_20, 8, 1, 1, 2);

        label_14 = new QLabel(Sextractor);
        label_14->setObjectName("label_14");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy4);
        label_14->setOpenExternalLinks(true);

        gridLayout_8->addWidget(label_14, 18, 1, 1, 2);

        label_t1 = new QLabel(Sextractor);
        label_t1->setObjectName("label_t1");

        gridLayout_8->addWidget(label_t1, 2, 1, 1, 1);

        deblend_thresh = new QLineEdit(Sextractor);
        deblend_thresh->setObjectName("deblend_thresh");

        gridLayout_8->addWidget(deblend_thresh, 9, 2, 1, 1);

        label_12 = new QLabel(Sextractor);
        label_12->setObjectName("label_12");

        gridLayout_8->addWidget(label_12, 20, 1, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_8->addItem(verticalSpacer_4, 23, 2, 1, 1);

        label_23 = new QLabel(Sextractor);
        label_23->setObjectName("label_23");

        gridLayout_8->addWidget(label_23, 14, 1, 1, 1);

        label_18 = new QLabel(Sextractor);
        label_18->setObjectName("label_18");

        gridLayout_8->addWidget(label_18, 9, 1, 1, 1);

        kron_fact = new QLineEdit(Sextractor);
        kron_fact->setObjectName("kron_fact");

        gridLayout_8->addWidget(kron_fact, 19, 2, 1, 1);

        label_25 = new QLabel(Sextractor);
        label_25->setObjectName("label_25");

        gridLayout_8->addWidget(label_25, 19, 1, 1, 1);

        magzero = new QLineEdit(Sextractor);
        magzero->setObjectName("magzero");

        gridLayout_8->addWidget(magzero, 22, 2, 1, 1);

        cleanCheckBox = new QCheckBox(Sextractor);
        cleanCheckBox->setObjectName("cleanCheckBox");
        cleanCheckBox->setChecked(true);

        gridLayout_8->addWidget(cleanCheckBox, 6, 1, 1, 1);

        label_24 = new QLabel(Sextractor);
        label_24->setObjectName("label_24");

        gridLayout_8->addWidget(label_24, 5, 1, 1, 1);

        label_t2 = new QLabel(Sextractor);
        label_t2->setObjectName("label_t2");

        gridLayout_8->addWidget(label_t2, 3, 1, 1, 1);

        apertureShape = new QComboBox(Sextractor);
        apertureShape->addItem(QString());
        apertureShape->addItem(QString());
        apertureShape->addItem(QString());
        apertureShape->setObjectName("apertureShape");

        gridLayout_8->addWidget(apertureShape, 20, 2, 1, 1);

        label_19 = new QLabel(Sextractor);
        label_19->setObjectName("label_19");

        gridLayout_8->addWidget(label_19, 10, 1, 1, 1);

        r_min = new QLineEdit(Sextractor);
        r_min->setObjectName("r_min");

        gridLayout_8->addWidget(r_min, 21, 2, 1, 1);

        label_13 = new QLabel(Sextractor);
        label_13->setObjectName("label_13");

        gridLayout_8->addWidget(label_13, 21, 1, 1, 1);

        thresh_offset = new QLineEdit(Sextractor);
        thresh_offset->setObjectName("thresh_offset");

        gridLayout_8->addWidget(thresh_offset, 3, 2, 1, 1);

        fwhm = new QSpinBox(Sextractor);
        fwhm->setObjectName("fwhm");
        fwhm->setMinimum(1);

        gridLayout_8->addWidget(fwhm, 14, 2, 1, 1);

        clean_param = new QLineEdit(Sextractor);
        clean_param->setObjectName("clean_param");

        gridLayout_8->addWidget(clean_param, 6, 2, 1, 1);

        minarea = new QLineEdit(Sextractor);
        minarea->setObjectName("minarea");

        gridLayout_8->addWidget(minarea, 4, 2, 1, 1);

        subpix = new QLineEdit(Sextractor);
        subpix->setObjectName("subpix");

        gridLayout_8->addWidget(subpix, 5, 2, 1, 1);

        label_21 = new QLabel(Sextractor);
        label_21->setObjectName("label_21");

        gridLayout_8->addWidget(label_21, 4, 1, 1, 1);

        label_38 = new QLabel(Sextractor);
        label_38->setObjectName("label_38");
        sizePolicy4.setHeightForWidth(label_38->sizePolicy().hasHeightForWidth());
        label_38->setSizePolicy(sizePolicy4);
        label_38->setOpenExternalLinks(true);

        gridLayout_8->addWidget(label_38, 0, 1, 1, 2);

        label_15 = new QLabel(Sextractor);
        label_15->setObjectName("label_15");

        gridLayout_8->addWidget(label_15, 22, 1, 1, 1);

        label_65 = new QLabel(Sextractor);
        label_65->setObjectName("label_65");

        gridLayout_8->addWidget(label_65, 11, 1, 1, 1);

        convFilterType = new QComboBox(Sextractor);
        convFilterType->addItem(QString());
        convFilterType->addItem(QString());
        convFilterType->addItem(QString());
        convFilterType->addItem(QString());
        convFilterType->addItem(QString());
        convFilterType->addItem(QString());
        convFilterType->setObjectName("convFilterType");

        gridLayout_8->addWidget(convFilterType, 11, 2, 1, 1);

        optionsBox->addItem(Sextractor, QString::fromUtf8("Sextractor"));
        StarFilters = new QWidget();
        StarFilters->setObjectName("StarFilters");
        StarFilters->setGeometry(QRect(0, 0, 141, 380));
        gridLayout_11 = new QGridLayout(StarFilters);
        gridLayout_11->setObjectName("gridLayout_11");
        dimmestPercent = new QLineEdit(StarFilters);
        dimmestPercent->setObjectName("dimmestPercent");

        gridLayout_11->addWidget(dimmestPercent, 7, 1, 1, 1);

        label_48 = new QLabel(StarFilters);
        label_48->setObjectName("label_48");
        label_48->setWordWrap(true);

        gridLayout_11->addWidget(label_48, 9, 0, 1, 3);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_11->addItem(verticalSpacer_3, 10, 0, 1, 1);

        resortQT = new QCheckBox(StarFilters);
        resortQT->setObjectName("resortQT");

        gridLayout_11->addWidget(resortQT, 0, 0, 1, 2);

        maxEllipse = new QLineEdit(StarFilters);
        maxEllipse->setObjectName("maxEllipse");

        gridLayout_11->addWidget(maxEllipse, 3, 1, 1, 1);

        label_54 = new QLabel(StarFilters);
        label_54->setObjectName("label_54");

        gridLayout_11->addWidget(label_54, 5, 0, 1, 1);

        label_55 = new QLabel(StarFilters);
        label_55->setObjectName("label_55");

        gridLayout_11->addWidget(label_55, 5, 2, 1, 1);

        label_52 = new QLabel(StarFilters);
        label_52->setObjectName("label_52");

        gridLayout_11->addWidget(label_52, 8, 2, 1, 1);

        saturationLimit = new QLineEdit(StarFilters);
        saturationLimit->setObjectName("saturationLimit");

        gridLayout_11->addWidget(saturationLimit, 8, 1, 1, 1);

        label_39 = new QLabel(StarFilters);
        label_39->setObjectName("label_39");

        gridLayout_11->addWidget(label_39, 3, 0, 1, 1);

        label_56 = new QLabel(StarFilters);
        label_56->setObjectName("label_56");

        gridLayout_11->addWidget(label_56, 2, 0, 1, 1);

        maxSize = new QLineEdit(StarFilters);
        maxSize->setObjectName("maxSize");

        gridLayout_11->addWidget(maxSize, 1, 1, 1, 1);

        label_43 = new QLabel(StarFilters);
        label_43->setObjectName("label_43");

        gridLayout_11->addWidget(label_43, 1, 0, 1, 1);

        label_40 = new QLabel(StarFilters);
        label_40->setObjectName("label_40");

        gridLayout_11->addWidget(label_40, 6, 0, 1, 1);

        keepNum = new QLineEdit(StarFilters);
        keepNum->setObjectName("keepNum");

        gridLayout_11->addWidget(keepNum, 5, 1, 1, 1);

        label_57 = new QLabel(StarFilters);
        label_57->setObjectName("label_57");

        gridLayout_11->addWidget(label_57, 2, 2, 1, 1);

        label_51 = new QLabel(StarFilters);
        label_51->setObjectName("label_51");

        gridLayout_11->addWidget(label_51, 7, 2, 1, 1);

        label_41 = new QLabel(StarFilters);
        label_41->setObjectName("label_41");

        gridLayout_11->addWidget(label_41, 7, 0, 1, 1);

        label_49 = new QLabel(StarFilters);
        label_49->setObjectName("label_49");

        gridLayout_11->addWidget(label_49, 1, 2, 1, 1);

        minSize = new QLineEdit(StarFilters);
        minSize->setObjectName("minSize");

        gridLayout_11->addWidget(minSize, 2, 1, 1, 1);

        label_46 = new QLabel(StarFilters);
        label_46->setObjectName("label_46");

        gridLayout_11->addWidget(label_46, 8, 0, 1, 1);

        brightestPercent = new QLineEdit(StarFilters);
        brightestPercent->setObjectName("brightestPercent");

        gridLayout_11->addWidget(brightestPercent, 6, 1, 1, 1);

        label_53 = new QLabel(StarFilters);
        label_53->setObjectName("label_53");

        gridLayout_11->addWidget(label_53, 3, 2, 1, 1);

        label_44 = new QLabel(StarFilters);
        label_44->setObjectName("label_44");

        gridLayout_11->addWidget(label_44, 6, 2, 1, 1);

        initialKeep = new QLineEdit(StarFilters);
        initialKeep->setObjectName("initialKeep");

        gridLayout_11->addWidget(initialKeep, 4, 1, 1, 1);

        label_58 = new QLabel(StarFilters);
        label_58->setObjectName("label_58");

        gridLayout_11->addWidget(label_58, 4, 0, 1, 1);

        label_60 = new QLabel(StarFilters);
        label_60->setObjectName("label_60");

        gridLayout_11->addWidget(label_60, 4, 2, 1, 1);

        optionsBox->addItem(StarFilters, QString::fromUtf8("Star Filtering"));
        Astrometry = new QWidget();
        Astrometry->setObjectName("Astrometry");
        Astrometry->setGeometry(QRect(0, 0, 98, 70));
        gridLayout_4 = new QGridLayout(Astrometry);
        gridLayout_4->setSpacing(0);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, 0, 0, 0);
        scrollArea_3 = new QScrollArea(Astrometry);
        scrollArea_3->setObjectName("scrollArea_3");
        scrollArea_3->setWidgetResizable(true);
        scrollAreaWidgetContents_3 = new QWidget();
        scrollAreaWidgetContents_3->setObjectName("scrollAreaWidgetContents_3");
        scrollAreaWidgetContents_3->setGeometry(QRect(0, 0, 201, 331));
        gridLayout_5 = new QGridLayout(scrollAreaWidgetContents_3);
        gridLayout_5->setSpacing(6);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(4, 4, 4, 0);
        solverTimeLimit = new QLineEdit(scrollAreaWidgetContents_3);
        solverTimeLimit->setObjectName("solverTimeLimit");

        gridLayout_5->addWidget(solverTimeLimit, 23, 2, 1, 1);

        radius = new QLineEdit(scrollAreaWidgetContents_3);
        radius->setObjectName("radius");

        gridLayout_5->addWidget(radius, 27, 2, 1, 1);

        label_9 = new QLabel(scrollAreaWidgetContents_3);
        label_9->setObjectName("label_9");

        gridLayout_5->addWidget(label_9, 27, 0, 1, 1);

        label_36 = new QLabel(scrollAreaWidgetContents_3);
        label_36->setObjectName("label_36");

        gridLayout_5->addWidget(label_36, 29, 0, 1, 1);

        minWidth = new QLineEdit(scrollAreaWidgetContents_3);
        minWidth->setObjectName("minWidth");

        gridLayout_5->addWidget(minWidth, 25, 2, 1, 1);

        label_37 = new QLabel(scrollAreaWidgetContents_3);
        label_37->setObjectName("label_37");

        gridLayout_5->addWidget(label_37, 30, 0, 1, 1);

        label_33 = new QLabel(scrollAreaWidgetContents_3);
        label_33->setObjectName("label_33");

        gridLayout_5->addWidget(label_33, 20, 0, 1, 1);

        inParallel = new QCheckBox(scrollAreaWidgetContents_3);
        inParallel->setObjectName("inParallel");
        inParallel->setChecked(true);

        gridLayout_5->addWidget(inParallel, 18, 0, 1, 1);

        label_28 = new QLabel(scrollAreaWidgetContents_3);
        label_28->setObjectName("label_28");

        gridLayout_5->addWidget(label_28, 26, 0, 1, 1);

        oddsToTune = new QLineEdit(scrollAreaWidgetContents_3);
        oddsToTune->setObjectName("oddsToTune");

        gridLayout_5->addWidget(oddsToTune, 30, 2, 1, 1);

        label_29 = new QLabel(scrollAreaWidgetContents_3);
        label_29->setObjectName("label_29");

        gridLayout_5->addWidget(label_29, 23, 0, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_7, 36, 2, 1, 1);

        label_27 = new QLabel(scrollAreaWidgetContents_3);
        label_27->setObjectName("label_27");

        gridLayout_5->addWidget(label_27, 25, 0, 1, 1);

        oddsToSolve = new QLineEdit(scrollAreaWidgetContents_3);
        oddsToSolve->setObjectName("oddsToSolve");

        gridLayout_5->addWidget(oddsToSolve, 28, 2, 1, 1);

        maxWidth = new QLineEdit(scrollAreaWidgetContents_3);
        maxWidth->setObjectName("maxWidth");

        gridLayout_5->addWidget(maxWidth, 26, 2, 1, 1);

        multiAlgo = new QComboBox(scrollAreaWidgetContents_3);
        multiAlgo->addItem(QString());
        multiAlgo->addItem(QString());
        multiAlgo->addItem(QString());
        multiAlgo->addItem(QString());
        multiAlgo->setObjectName("multiAlgo");

        gridLayout_5->addWidget(multiAlgo, 20, 2, 1, 1);

        oddsToKeep = new QLineEdit(scrollAreaWidgetContents_3);
        oddsToKeep->setObjectName("oddsToKeep");

        gridLayout_5->addWidget(oddsToKeep, 29, 2, 1, 1);

        label_16 = new QLabel(scrollAreaWidgetContents_3);
        label_16->setObjectName("label_16");

        gridLayout_5->addWidget(label_16, 22, 0, 1, 1);

        label_35 = new QLabel(scrollAreaWidgetContents_3);
        label_35->setObjectName("label_35");

        gridLayout_5->addWidget(label_35, 28, 0, 1, 1);

        downsample = new QSpinBox(scrollAreaWidgetContents_3);
        downsample->setObjectName("downsample");
        downsample->setMinimum(1);
        downsample->setMaximum(5);

        gridLayout_5->addWidget(downsample, 22, 2, 1, 1);

        resort = new QCheckBox(scrollAreaWidgetContents_3);
        resort->setObjectName("resort");

        gridLayout_5->addWidget(resort, 18, 2, 1, 1);

        autoDown = new QCheckBox(scrollAreaWidgetContents_3);
        autoDown->setObjectName("autoDown");

        gridLayout_5->addWidget(autoDown, 21, 0, 1, 3);

        scrollArea_3->setWidget(scrollAreaWidgetContents_3);

        gridLayout_4->addWidget(scrollArea_3, 2, 0, 1, 1);

        optionsBox->addItem(Astrometry, QString::fromUtf8("Astrometry"));

        gridLayout->addWidget(optionsBox, 3, 0, 1, 1);

        optionsTab->addTab(tab_4, QString());

        verticalLayout_4->addWidget(optionsTab);

        horSplitter->addWidget(widget);
        widget_3 = new QWidget(horSplitter);
        widget_3->setObjectName("widget_3");
        verticalLayout_6 = new QVBoxLayout(widget_3);
        verticalLayout_6->setObjectName("verticalLayout_6");
        verticalLayout_6->setContentsMargins(3, 3, 3, 3);
        vertSplitter = new QSplitter(widget_3);
        vertSplitter->setObjectName("vertSplitter");
        vertSplitter->setOrientation(Qt::Vertical);
        verticalLayoutWidget = new QWidget(vertSplitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayout_2 = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        fileNameDisplay = new QLabel(verticalLayoutWidget);
        fileNameDisplay->setObjectName("fileNameDisplay");
        fileNameDisplay->setWordWrap(true);

        verticalLayout_2->addWidget(fileNameDisplay);

        imageScrollArea = new QScrollArea(verticalLayoutWidget);
        imageScrollArea->setObjectName("imageScrollArea");
        imageScrollArea->setWidgetResizable(true);
        imageScrollArea->setAlignment(Qt::AlignCenter);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 518, 141));
        gridLayout_2 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        Image = new ImageLabel(scrollAreaWidgetContents);
        Image->setObjectName("Image");
        sizePolicy.setHeightForWidth(Image->sizePolicy().hasHeightForWidth());
        Image->setSizePolicy(sizePolicy);
        Image->setAlignment(Qt::AlignCenter);

        gridLayout_2->addWidget(Image, 0, 7, 1, 1);

        imageScrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(imageScrollArea);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setSpacing(0);
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        horizontalLayout_8->setContentsMargins(-1, 0, -1, -1);
        mouseInfo = new QLabel(verticalLayoutWidget);
        mouseInfo->setObjectName("mouseInfo");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(mouseInfo->sizePolicy().hasHeightForWidth());
        mouseInfo->setSizePolicy(sizePolicy5);
        mouseInfo->setMaximumSize(QSize(16777215, 15));
        mouseInfo->setWordWrap(false);

        horizontalLayout_8->addWidget(mouseInfo);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_2);

        setSubFrame = new QPushButton(verticalLayoutWidget);
        setSubFrame->setObjectName("setSubFrame");
        setSubFrame->setCheckable(true);

        horizontalLayout_8->addWidget(setSubFrame);

        showStars = new QCheckBox(verticalLayoutWidget);
        showStars->setObjectName("showStars");
        showStars->setChecked(true);

        horizontalLayout_8->addWidget(showStars);

        starOptions = new QComboBox(verticalLayoutWidget);
        starOptions->addItem(QString());
        starOptions->addItem(QString());
        starOptions->addItem(QString());
        starOptions->addItem(QString());
        starOptions->setObjectName("starOptions");

        horizontalLayout_8->addWidget(starOptions);

        channelSelection = new QComboBox(verticalLayoutWidget);
        channelSelection->addItem(QString());
        channelSelection->addItem(QString());
        channelSelection->addItem(QString());
        channelSelection->addItem(QString());
        channelSelection->addItem(QString());
        channelSelection->setObjectName("channelSelection");

        horizontalLayout_8->addWidget(channelSelection);


        verticalLayout_2->addLayout(horizontalLayout_8);

        vertSplitter->addWidget(verticalLayoutWidget);
        tabWidget = new QTabWidget(vertSplitter);
        tabWidget->setObjectName("tabWidget");
        logOutput = new QWidget();
        logOutput->setObjectName("logOutput");
        gridLayout_6 = new QGridLayout(logOutput);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        logDisplay = new QPlainTextEdit(logOutput);
        logDisplay->setObjectName("logDisplay");

        gridLayout_6->addWidget(logDisplay, 3, 0, 1, 1);

        tabWidget->addTab(logOutput, QString());
        resultsTableView = new QWidget();
        resultsTableView->setObjectName("resultsTableView");
        gridLayout_7 = new QGridLayout(resultsTableView);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(0, 0, 0, 0);
        resultsTable = new QTableWidget(resultsTableView);
        resultsTable->setObjectName("resultsTable");
        resultsTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        resultsTable->setDragDropOverwriteMode(false);

        gridLayout_7->addWidget(resultsTable, 4, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(-1, 0, -1, -1);
        showExtractorParams = new QCheckBox(resultsTableView);
        showExtractorParams->setObjectName("showExtractorParams");
        showExtractorParams->setChecked(false);

        horizontalLayout_3->addWidget(showExtractorParams);

        showAstrometryParams = new QCheckBox(resultsTableView);
        showAstrometryParams->setObjectName("showAstrometryParams");
        showAstrometryParams->setChecked(false);

        horizontalLayout_3->addWidget(showAstrometryParams);

        showSolutionDetails = new QCheckBox(resultsTableView);
        showSolutionDetails->setObjectName("showSolutionDetails");
        showSolutionDetails->setChecked(true);

        horizontalLayout_3->addWidget(showSolutionDetails);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);


        gridLayout_7->addLayout(horizontalLayout_3, 0, 0, 1, 1);

        tabWidget->addTab(resultsTableView, QString());
        vertSplitter->addWidget(tabWidget);

        verticalLayout_6->addWidget(vertSplitter);

        horSplitter->addWidget(widget_3);
        frame = new QFrame(horSplitter);
        frame->setObjectName("frame");
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        verticalLayout_5 = new QVBoxLayout(frame);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(3, 3, 3, 3);
        verticalLayout_3 = new QVBoxLayout();
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setSpacing(6);
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        horizontalLayout_7->setSizeConstraint(QLayout::SetDefaultConstraint);
        horizontalLayout_7->setContentsMargins(-1, 0, -1, -1);
        label_50 = new QLabel(frame);
        label_50->setObjectName("label_50");
        sizePolicy4.setHeightForWidth(label_50->sizePolicy().hasHeightForWidth());
        label_50->setSizePolicy(sizePolicy4);
        label_50->setWordWrap(true);

        horizontalLayout_7->addWidget(label_50);

        showFluxInfo = new QCheckBox(frame);
        showFluxInfo->setObjectName("showFluxInfo");
        showFluxInfo->setChecked(false);

        horizontalLayout_7->addWidget(showFluxInfo);

        showStarShapeInfo = new QCheckBox(frame);
        showStarShapeInfo->setObjectName("showStarShapeInfo");
        showStarShapeInfo->setChecked(false);

        horizontalLayout_7->addWidget(showStarShapeInfo);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_3);


        verticalLayout_3->addLayout(horizontalLayout_7);

        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setSpacing(6);
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        horizontalLayout_9->setContentsMargins(-1, 0, -1, -1);
        ClearStars = new QPushButton(frame);
        ClearStars->setObjectName("ClearStars");

        horizontalLayout_9->addWidget(ClearStars);

        exportStarTable = new QPushButton(frame);
        exportStarTable->setObjectName("exportStarTable");

        horizontalLayout_9->addWidget(exportStarTable);


        verticalLayout_3->addLayout(horizontalLayout_9);

        starTable = new QTableWidget(frame);
        starTable->setObjectName("starTable");
        starTable->setEditTriggers(QAbstractItemView::NoEditTriggers);
        starTable->setProperty("showDropIndicator", QVariant(false));
        starTable->setDragDropOverwriteMode(false);

        verticalLayout_3->addWidget(starTable);


        verticalLayout_5->addLayout(verticalLayout_3);

        horSplitter->addWidget(frame);

        verticalLayout->addWidget(horSplitter);

        gridLayout_14 = new QGridLayout();
        gridLayout_14->setObjectName("gridLayout_14");
        gridLayout_14->setContentsMargins(-1, 0, -1, -1);
        groupBox_2 = new QGroupBox(centralwidget);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_18 = new QGridLayout(groupBox_2);
        gridLayout_18->setObjectName("gridLayout_18");
        gridLayout_18->setContentsMargins(0, 10, 0, 0);
        extractionProfile = new QComboBox(groupBox_2);
        extractionProfile->addItem(QString());
        extractionProfile->setObjectName("extractionProfile");
        sizePolicy3.setHeightForWidth(extractionProfile->sizePolicy().hasHeightForWidth());
        extractionProfile->setSizePolicy(sizePolicy3);

        gridLayout_18->addWidget(extractionProfile, 0, 2, 1, 1);

        editExtractorProfile = new QPushButton(groupBox_2);
        editExtractorProfile->setObjectName("editExtractorProfile");

        gridLayout_18->addWidget(editExtractorProfile, 0, 3, 1, 1);

        startExtraction = new QPushButton(groupBox_2);
        startExtraction->setObjectName("startExtraction");

        gridLayout_18->addWidget(startExtraction, 1, 1, 1, 3);

        extractorTypeForExtraction = new QComboBox(groupBox_2);
        extractorTypeForExtraction->addItem(QString());
        extractorTypeForExtraction->addItem(QString());
        extractorTypeForExtraction->addItem(QString());
        extractorTypeForExtraction->addItem(QString());
        extractorTypeForExtraction->setObjectName("extractorTypeForExtraction");

        gridLayout_18->addWidget(extractorTypeForExtraction, 0, 1, 1, 1);


        gridLayout_14->addWidget(groupBox_2, 3, 4, 2, 1);

        groupBox_3 = new QGroupBox(centralwidget);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_17 = new QGridLayout(groupBox_3);
        gridLayout_17->setObjectName("gridLayout_17");
        gridLayout_17->setContentsMargins(0, 10, 0, 0);
        solverProfile = new QComboBox(groupBox_3);
        solverProfile->addItem(QString());
        solverProfile->setObjectName("solverProfile");
        sizePolicy3.setHeightForWidth(solverProfile->sizePolicy().hasHeightForWidth());
        solverProfile->setSizePolicy(sizePolicy3);

        gridLayout_17->addWidget(solverProfile, 2, 2, 1, 1);

        extractorTypeForSolving = new QComboBox(groupBox_3);
        extractorTypeForSolving->addItem(QString());
        extractorTypeForSolving->addItem(QString());
        extractorTypeForSolving->addItem(QString());
        extractorTypeForSolving->setObjectName("extractorTypeForSolving");

        gridLayout_17->addWidget(extractorTypeForSolving, 2, 0, 1, 1);

        solverType = new QComboBox(groupBox_3);
        solverType->addItem(QString());
        solverType->addItem(QString());
        solverType->addItem(QString());
        solverType->addItem(QString());
        solverType->addItem(QString());
        solverType->setObjectName("solverType");

        gridLayout_17->addWidget(solverType, 2, 1, 1, 1);

        startSolving = new QPushButton(groupBox_3);
        startSolving->setObjectName("startSolving");

        gridLayout_17->addWidget(startSolving, 4, 0, 1, 4);

        editSolverProfile = new QPushButton(groupBox_3);
        editSolverProfile->setObjectName("editSolverProfile");

        gridLayout_17->addWidget(editSolverProfile, 2, 3, 1, 1);


        gridLayout_14->addWidget(groupBox_3, 3, 5, 2, 1);

        ClearResults = new QPushButton(centralwidget);
        ClearResults->setObjectName("ClearResults");

        gridLayout_14->addWidget(ClearResults, 3, 6, 1, 1);

        Abort = new QPushButton(centralwidget);
        Abort->setObjectName("Abort");

        gridLayout_14->addWidget(Abort, 4, 6, 1, 1);

        label_32 = new QLabel(centralwidget);
        label_32->setObjectName("label_32");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(label_32->sizePolicy().hasHeightForWidth());
        label_32->setSizePolicy(sizePolicy6);
        label_32->setMaximumSize(QSize(16777215, 15));
        label_32->setAlignment(Qt::AlignCenter);

        gridLayout_14->addWidget(label_32, 3, 9, 1, 1);

        trials = new QSpinBox(centralwidget);
        trials->setObjectName("trials");
        trials->setMinimum(1);
        trials->setMaximum(100);

        gridLayout_14->addWidget(trials, 3, 10, 1, 1);

        exportResultsTable = new QPushButton(centralwidget);
        exportResultsTable->setObjectName("exportResultsTable");

        gridLayout_14->addWidget(exportResultsTable, 4, 9, 1, 2);


        verticalLayout->addLayout(gridLayout_14);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setSpacing(0);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setSizeConstraint(QLayout::SetDefaultConstraint);
        horizontalLayout_6->setContentsMargins(-1, 0, -1, -1);
        status = new QLabel(centralwidget);
        status->setObjectName("status");
        sizePolicy3.setHeightForWidth(status->sizePolicy().hasHeightForWidth());
        status->setSizePolicy(sizePolicy3);
        status->setMaximumSize(QSize(16777215, 15));

        horizontalLayout_6->addWidget(status);

        progressBar = new QProgressBar(centralwidget);
        progressBar->setObjectName("progressBar");
        progressBar->setMaximum(10);
        progressBar->setValue(0);

        horizontalLayout_6->addWidget(progressBar);


        verticalLayout->addLayout(horizontalLayout_6);

        MainWindow->setCentralWidget(centralwidget);
        statusbar = new QStatusBar(MainWindow);
        statusbar->setObjectName("statusbar");
        statusbar->setEnabled(true);
        MainWindow->setStatusBar(statusbar);

        retranslateUi(MainWindow);

        optionsTab->setCurrentIndex(0);
        toolBox->setCurrentIndex(0);
        toolBox->layout()->setSpacing(6);
        stellarSolverLogLevel->setCurrentIndex(1);
        logLevel->setCurrentIndex(0);
        optionsProfile->setCurrentIndex(0);
        optionsBox->setCurrentIndex(0);
        optionsBox->layout()->setSpacing(6);
        apertureShape->setCurrentIndex(1);
        multiAlgo->setCurrentIndex(0);
        channelSelection->setCurrentIndex(1);
        tabWidget->setCurrentIndex(0);
        extractionProfile->setCurrentIndex(0);
        solverProfile->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QCoreApplication::translate("MainWindow", "StellarSolver Astrometry Tester", nullptr));
        ImageLoad->setText(QCoreApplication::translate("MainWindow", "Load Image", nullptr));
        ImageSave->setText(QCoreApplication::translate("MainWindow", "Save Image", nullptr));
        zoomIn->setText(QCoreApplication::translate("MainWindow", "Zoom In", nullptr));
        zoomOut->setText(QCoreApplication::translate("MainWindow", "Zoom Out", nullptr));
        AutoScale->setText(QCoreApplication::translate("MainWindow", "Auto Scale", nullptr));
        label_47->setText(QCoreApplication::translate("MainWindow", "<html><head/><body><p align=\"center\"><img src=\":/StellarSolverIcon.png\" width=\"125\"/></p><p align=\"center\">StellarSolver Library<br/>\302\251 2020 by <br/>Rob Lancaster<br/>GPL v.3</p><p align=\"center\">built on:<br/><a href=\"http://astrometry.net/doc/readme.html\"><span style=\" text-decoration: underline; color:#0068da;\">astrometry.net</span></a><br/><a href=\"https://sep.readthedocs.io/en/v1.0.x/\"><span style=\" text-decoration: underline; color:#0068da;\">sextractor (SEP)</span></a></p></body></html> ", nullptr));
        toolBox->setItemText(toolBox->indexOf(page), QCoreApplication::translate("MainWindow", "StellarSolver", nullptr));
        label_34->setText(QCoreApplication::translate("MainWindow", "Astrometry:", nullptr));
        logToFile->setText(QCoreApplication::translate("MainWindow", "Astrometry Log to File", nullptr));
        label_59->setText(QCoreApplication::translate("MainWindow", "StellarSolver:", nullptr));
        stellarSolverLogLevel->setItemText(0, QCoreApplication::translate("MainWindow", "None", nullptr));
        stellarSolverLogLevel->setItemText(1, QCoreApplication::translate("MainWindow", "Normal", nullptr));
        stellarSolverLogLevel->setItemText(2, QCoreApplication::translate("MainWindow", "Verbose", nullptr));

        logLevel->setItemText(0, QCoreApplication::translate("MainWindow", "LOG_NONE", nullptr));
        logLevel->setItemText(1, QCoreApplication::translate("MainWindow", "LOG_ERROR", nullptr));
        logLevel->setItemText(2, QCoreApplication::translate("MainWindow", "LOG_MSG", nullptr));
        logLevel->setItemText(3, QCoreApplication::translate("MainWindow", "LOG_VERB", nullptr));
        logLevel->setItemText(4, QCoreApplication::translate("MainWindow", "LOG_ALL", nullptr));

        label_61->setText(QCoreApplication::translate("MainWindow", "Log File:", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_5), QCoreApplication::translate("MainWindow", "Logging", nullptr));
        configFilePath->setText(QString());
        label_11->setText(QCoreApplication::translate("MainWindow", "Temp", nullptr));
        basePath->setText(QString());
        openTemp->setText(QCoreApplication::translate("MainWindow", "Open Temp", nullptr));
        apiKey->setText(QString());
        label_3->setText(QCoreApplication::translate("MainWindow", "Config", nullptr));
        label_42->setText(QCoreApplication::translate("MainWindow", "WCSInfo", nullptr));
        label->setText(QCoreApplication::translate("MainWindow", "<a href=\"https://www.astromatic.net/software/sextractor\">Sextractor</a>\n"
"", nullptr));
        astapPath->setText(QString());
        label_63->setText(QCoreApplication::translate("MainWindow", "Online Server", nullptr));
        label_2->setText(QCoreApplication::translate("MainWindow", "Solver", nullptr));
        sextractorPath->setText(QString());
        onlineServer->setText(QString());
        generateAstrometryConfig->setText(QCoreApplication::translate("MainWindow", "Auto Generate Astro Config", nullptr));
        label_45->setText(QCoreApplication::translate("MainWindow", "<a href=\"https://www.hnsky.org/astap.htm\">ASTAP</a>", nullptr));
        label_10->setText(QCoreApplication::translate("MainWindow", "<a href= \"http://astrometry.net/use.html\">Astrometry</a> or <a href=\"https://adgsoftware.com/ansvr/\">ANSVR</a>", nullptr));
        label_64->setText(QCoreApplication::translate("MainWindow", "<a href=\"https://github.com/Jusas/WatneyAstrometry\">Watney</a>", nullptr));
        watneyPath->setText(QString());
        cleanupTemp->setText(QCoreApplication::translate("MainWindow", "Cleanup Temporary Files After Processes", nullptr));
        label_62->setText(QCoreApplication::translate("MainWindow", "API Key", nullptr));
        setPathsAutomatically->setItemText(0, QCoreApplication::translate("MainWindow", "Linux Default", nullptr));
        setPathsAutomatically->setItemText(1, QCoreApplication::translate("MainWindow", "Linux KStars Internal ", nullptr));
        setPathsAutomatically->setItemText(2, QCoreApplication::translate("MainWindow", "Mac Homebrew", nullptr));
        setPathsAutomatically->setItemText(3, QCoreApplication::translate("MainWindow", "Windows ANSVR", nullptr));
        setPathsAutomatically->setItemText(4, QCoreApplication::translate("MainWindow", "Windows Cygwin", nullptr));

        toolBox->setItemText(toolBox->indexOf(page_2), QCoreApplication::translate("MainWindow", "Online/External Program Options", nullptr));
        label_6->setText(QCoreApplication::translate("MainWindow", "Units", nullptr));
        scale_low->setText(QString());
        use_position->setText(QCoreApplication::translate("MainWindow", "Use Position", nullptr));
        label_7->setText(QCoreApplication::translate("MainWindow", "RA", nullptr));
        units->setItemText(0, QCoreApplication::translate("MainWindow", "degwidth", nullptr));
        units->setItemText(1, QCoreApplication::translate("MainWindow", "arcminwidth", nullptr));
        units->setItemText(2, QCoreApplication::translate("MainWindow", "arcsecperpix", nullptr));
        units->setItemText(3, QCoreApplication::translate("MainWindow", "focalmm", nullptr));

        deString->setText(QString());
        label_31->setText(QCoreApplication::translate("MainWindow", "Note: These settings are not saved in the profile.  They change with every image.", nullptr));
        raString->setText(QString());
        label_4->setText(QCoreApplication::translate("MainWindow", "Low", nullptr));
        label_5->setText(QCoreApplication::translate("MainWindow", "High", nullptr));
        ra->setText(QString());
        use_scale->setText(QCoreApplication::translate("MainWindow", "Use Scale", nullptr));
        label_8->setText(QCoreApplication::translate("MainWindow", "DEC", nullptr));
        autoUpdateScaleAndPosition->setText(QCoreApplication::translate("MainWindow", "Auto Update Scale and Position", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_4), QCoreApplication::translate("MainWindow", "Scale/Position", nullptr));
        removeIndexPath->setText(QCoreApplication::translate("MainWindow", "Remove", nullptr));
        useAllIndexes->setItemText(0, QCoreApplication::translate("MainWindow", "Auto Index Files", nullptr));
        useAllIndexes->setItemText(1, QCoreApplication::translate("MainWindow", "Filter indexes", nullptr));
        useAllIndexes->setItemText(2, QCoreApplication::translate("MainWindow", "Use Last Solve", nullptr));

        label_66->setText(QCoreApplication::translate("MainWindow", "Index Files to use:", nullptr));
        addIndexPath->setText(QCoreApplication::translate("MainWindow", "Add", nullptr));
        label_26->setText(QCoreApplication::translate("MainWindow", "Index File Folder Paths", nullptr));
        label_30->setText(QCoreApplication::translate("MainWindow", "Index Files in Selected Folder:", nullptr));
        toolBox->setItemText(toolBox->indexOf(page_3), QCoreApplication::translate("MainWindow", "Index Files", nullptr));
        optionsTab->setTabText(optionsTab->indexOf(tab_3), QCoreApplication::translate("MainWindow", "Main Options", nullptr));
        loadSettings->setText(QCoreApplication::translate("MainWindow", "Load", nullptr));
        saveSettings->setText(QCoreApplication::translate("MainWindow", "Save", nullptr));
        optionsProfile->setItemText(0, QCoreApplication::translate("MainWindow", "Unsaved Options", nullptr));

        addOptionProfile->setText(QCoreApplication::translate("MainWindow", "+", nullptr));
        removeOptionProfile->setText(QCoreApplication::translate("MainWindow", "-", nullptr));
        thresh_multiple->setText(QCoreApplication::translate("MainWindow", "2.0", nullptr));
        partition->setText(QCoreApplication::translate("MainWindow", "Partition?", nullptr));
        showConv->setText(QCoreApplication::translate("MainWindow", "Show Conv Filter", nullptr));
        deblend_contrast->setText(QCoreApplication::translate("MainWindow", "1", nullptr));
        label_20->setText(QCoreApplication::translate("MainWindow", "<a href=\"https://sep.readthedocs.io/en/v1.0.x/api/sep.extract.html\">Deblending Params</a>", nullptr));
        label_14->setText(QCoreApplication::translate("MainWindow", "<a href = \"https://sep.readthedocs.io/en/v1.0.x/api/sep.sum_ellipse.html\">Photometry Params</a>", nullptr));
        label_t1->setText(QCoreApplication::translate("MainWindow", "Thresh Mulitple", nullptr));
        deblend_thresh->setText(QCoreApplication::translate("MainWindow", "32", nullptr));
        label_12->setText(QCoreApplication::translate("MainWindow", "Shape", nullptr));
        label_23->setText(QCoreApplication::translate("MainWindow", "Filter FWHM", nullptr));
        label_18->setText(QCoreApplication::translate("MainWindow", "Deblend Thresh", nullptr));
        kron_fact->setText(QCoreApplication::translate("MainWindow", "3.5", nullptr));
        label_25->setText(QCoreApplication::translate("MainWindow", "Kron Facy", nullptr));
        magzero->setText(QCoreApplication::translate("MainWindow", "20", nullptr));
        cleanCheckBox->setText(QCoreApplication::translate("MainWindow", "Clean?", nullptr));
        label_24->setText(QCoreApplication::translate("MainWindow", "Sub Pix", nullptr));
        label_t2->setText(QCoreApplication::translate("MainWindow", "Thresh Offset", nullptr));
        apertureShape->setItemText(0, QCoreApplication::translate("MainWindow", "Auto", nullptr));
        apertureShape->setItemText(1, QCoreApplication::translate("MainWindow", "Circle", nullptr));
        apertureShape->setItemText(2, QCoreApplication::translate("MainWindow", "Ellipse", nullptr));

        label_19->setText(QCoreApplication::translate("MainWindow", "Min Cont.", nullptr));
        r_min->setText(QCoreApplication::translate("MainWindow", "3.5", nullptr));
        label_13->setText(QCoreApplication::translate("MainWindow", "r_min", nullptr));
        thresh_offset->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        clean_param->setText(QCoreApplication::translate("MainWindow", "1", nullptr));
        minarea->setText(QCoreApplication::translate("MainWindow", "5", nullptr));
        subpix->setText(QCoreApplication::translate("MainWindow", "5", nullptr));
        label_21->setText(QCoreApplication::translate("MainWindow", "Min Area", nullptr));
        label_38->setText(QCoreApplication::translate("MainWindow", "<a href = \"https://sep.readthedocs.io/en/v1.0.x/api/sep.extract.html\" >Extraction Params</a>", nullptr));
        label_15->setText(QCoreApplication::translate("MainWindow", "magzero", nullptr));
        label_65->setText(QCoreApplication::translate("MainWindow", "Conv Filter", nullptr));
        convFilterType->setItemText(0, QCoreApplication::translate("MainWindow", "Default", nullptr));
        convFilterType->setItemText(1, QCoreApplication::translate("MainWindow", "Custom", nullptr));
        convFilterType->setItemText(2, QCoreApplication::translate("MainWindow", "Gaussian", nullptr));
        convFilterType->setItemText(3, QCoreApplication::translate("MainWindow", "Mexican Hat", nullptr));
        convFilterType->setItemText(4, QCoreApplication::translate("MainWindow", "Top Hat", nullptr));
        convFilterType->setItemText(5, QCoreApplication::translate("MainWindow", "Ring", nullptr));

        optionsBox->setItemText(optionsBox->indexOf(Sextractor), QCoreApplication::translate("MainWindow", "Sextractor", nullptr));
        dimmestPercent->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_48->setText(QCoreApplication::translate("MainWindow", "(Make these settings 0 to disable them)", nullptr));
        resortQT->setText(QCoreApplication::translate("MainWindow", "Resort", nullptr));
        maxEllipse->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_54->setText(QCoreApplication::translate("MainWindow", "Keep #", nullptr));
        label_55->setText(QCoreApplication::translate("MainWindow", "stars", nullptr));
        label_52->setText(QCoreApplication::translate("MainWindow", "%", nullptr));
        saturationLimit->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_39->setText(QCoreApplication::translate("MainWindow", "Max Ell", nullptr));
        label_56->setText(QCoreApplication::translate("MainWindow", "Min Size", nullptr));
        maxSize->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_43->setText(QCoreApplication::translate("MainWindow", "Max Size", nullptr));
        label_40->setText(QCoreApplication::translate("MainWindow", "Cut Bright", nullptr));
        keepNum->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_57->setText(QCoreApplication::translate("MainWindow", "px", nullptr));
        label_51->setText(QCoreApplication::translate("MainWindow", "%", nullptr));
        label_41->setText(QCoreApplication::translate("MainWindow", "Cut Dim", nullptr));
        label_49->setText(QCoreApplication::translate("MainWindow", "px", nullptr));
        minSize->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_46->setText(QCoreApplication::translate("MainWindow", "Sat. Lim", nullptr));
        brightestPercent->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_53->setText(QCoreApplication::translate("MainWindow", "a/b", nullptr));
        label_44->setText(QCoreApplication::translate("MainWindow", "%", nullptr));
        initialKeep->setText(QCoreApplication::translate("MainWindow", "0", nullptr));
        label_58->setText(QCoreApplication::translate("MainWindow", "InitialKeep", nullptr));
        label_60->setText(QCoreApplication::translate("MainWindow", "stars", nullptr));
        optionsBox->setItemText(optionsBox->indexOf(StarFilters), QCoreApplication::translate("MainWindow", "Star Filtering", nullptr));
        solverTimeLimit->setText(QCoreApplication::translate("MainWindow", "600", nullptr));
        label_9->setText(QCoreApplication::translate("MainWindow", "Radius", nullptr));
        label_36->setText(QCoreApplication::translate("MainWindow", "KeepOdds", nullptr));
        minWidth->setText(QCoreApplication::translate("MainWindow", "0.1", nullptr));
        label_37->setText(QCoreApplication::translate("MainWindow", "TuneOdds", nullptr));
        label_33->setText(QCoreApplication::translate("MainWindow", "MultiAlgo", nullptr));
        inParallel->setText(QCoreApplication::translate("MainWindow", "InParallel", nullptr));
        label_28->setText(QCoreApplication::translate("MainWindow", "MaxWidth", nullptr));
        oddsToTune->setText(QString());
        label_29->setText(QCoreApplication::translate("MainWindow", "MaxTime", nullptr));
        label_27->setText(QCoreApplication::translate("MainWindow", "MinWidth", nullptr));
        oddsToSolve->setText(QString());
        maxWidth->setText(QCoreApplication::translate("MainWindow", "180", nullptr));
        multiAlgo->setItemText(0, QCoreApplication::translate("MainWindow", "None", nullptr));
        multiAlgo->setItemText(1, QCoreApplication::translate("MainWindow", "MultiScales", nullptr));
        multiAlgo->setItemText(2, QCoreApplication::translate("MainWindow", "MultiDepths", nullptr));
        multiAlgo->setItemText(3, QCoreApplication::translate("MainWindow", "Auto", nullptr));

        oddsToKeep->setText(QString());
        label_16->setText(QCoreApplication::translate("MainWindow", "DownSam", nullptr));
        label_35->setText(QCoreApplication::translate("MainWindow", "SolveOdds", nullptr));
        resort->setText(QCoreApplication::translate("MainWindow", "Resort", nullptr));
        autoDown->setText(QCoreApplication::translate("MainWindow", "AutoDownsample", nullptr));
        optionsBox->setItemText(optionsBox->indexOf(Astrometry), QCoreApplication::translate("MainWindow", "Astrometry", nullptr));
        optionsTab->setTabText(optionsTab->indexOf(tab_4), QCoreApplication::translate("MainWindow", "ProfileEditor", nullptr));
        fileNameDisplay->setText(QString());
        Image->setText(QString());
        mouseInfo->setText(QString());
        setSubFrame->setText(QCoreApplication::translate("MainWindow", "SubFrame", nullptr));
        showStars->setText(QCoreApplication::translate("MainWindow", "Stars", nullptr));
        starOptions->setItemText(0, QCoreApplication::translate("MainWindow", "Ellipse", nullptr));
        starOptions->setItemText(1, QCoreApplication::translate("MainWindow", "Circle", nullptr));
        starOptions->setItemText(2, QCoreApplication::translate("MainWindow", "HFD", nullptr));
        starOptions->setItemText(3, QCoreApplication::translate("MainWindow", "2 x HFD", nullptr));

        channelSelection->setItemText(0, QCoreApplication::translate("MainWindow", "Red", nullptr));
        channelSelection->setItemText(1, QCoreApplication::translate("MainWindow", "Green", nullptr));
        channelSelection->setItemText(2, QCoreApplication::translate("MainWindow", "Blue", nullptr));
        channelSelection->setItemText(3, QCoreApplication::translate("MainWindow", "Average RGB", nullptr));
        channelSelection->setItemText(4, QCoreApplication::translate("MainWindow", "Integrated RGB", nullptr));

#if QT_CONFIG(tooltip)
        channelSelection->setToolTip(QCoreApplication::translate("MainWindow", "The Color Channel to use for Star Extraction and Solving of RGB Images.  Note that this does not apply to MonoChromatic images, which only have one channel.", nullptr));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(logOutput), QCoreApplication::translate("MainWindow", "Log Output", nullptr));
        showExtractorParams->setText(QCoreApplication::translate("MainWindow", "Star Extractor Params", nullptr));
        showAstrometryParams->setText(QCoreApplication::translate("MainWindow", "Astrometry Params", nullptr));
        showSolutionDetails->setText(QCoreApplication::translate("MainWindow", "Solution", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(resultsTableView), QCoreApplication::translate("MainWindow", "Results Table", nullptr));
        label_50->setText(QCoreApplication::translate("MainWindow", "Star Table", nullptr));
        showFluxInfo->setText(QCoreApplication::translate("MainWindow", "Flux", nullptr));
        showStarShapeInfo->setText(QCoreApplication::translate("MainWindow", "Ellipse", nullptr));
        ClearStars->setText(QCoreApplication::translate("MainWindow", "Clear", nullptr));
        exportStarTable->setText(QCoreApplication::translate("MainWindow", "Export", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("MainWindow", "Source Extraction", nullptr));
        extractionProfile->setItemText(0, QCoreApplication::translate("MainWindow", "Options in Editor", nullptr));

        editExtractorProfile->setText(QCoreApplication::translate("MainWindow", "Edit", nullptr));
        startExtraction->setText(QCoreApplication::translate("MainWindow", "Start Source Extraction", nullptr));
        extractorTypeForExtraction->setItemText(0, QCoreApplication::translate("MainWindow", "Internal SEP", nullptr));
        extractorTypeForExtraction->setItemText(1, QCoreApplication::translate("MainWindow", "Internal SEP w/HFR", nullptr));
        extractorTypeForExtraction->setItemText(2, QCoreApplication::translate("MainWindow", "External SExtractor", nullptr));
        extractorTypeForExtraction->setItemText(3, QCoreApplication::translate("MainWindow", "External SExtractor w/HFR", nullptr));

        groupBox_3->setTitle(QCoreApplication::translate("MainWindow", "Solve", nullptr));
        solverProfile->setItemText(0, QCoreApplication::translate("MainWindow", "Options in Editor", nullptr));

        extractorTypeForSolving->setItemText(0, QCoreApplication::translate("MainWindow", "Internal SEP", nullptr));
        extractorTypeForSolving->setItemText(1, QCoreApplication::translate("MainWindow", "External SExtractor", nullptr));
        extractorTypeForSolving->setItemText(2, QCoreApplication::translate("MainWindow", "BuiltIn Method", nullptr));

        solverType->setItemText(0, QCoreApplication::translate("MainWindow", "Internal Solver", nullptr));
        solverType->setItemText(1, QCoreApplication::translate("MainWindow", "Local Astrometry", nullptr));
        solverType->setItemText(2, QCoreApplication::translate("MainWindow", "Local ASTAP", nullptr));
        solverType->setItemText(3, QCoreApplication::translate("MainWindow", "Watney Solver", nullptr));
        solverType->setItemText(4, QCoreApplication::translate("MainWindow", "Online Astrometry", nullptr));

        startSolving->setText(QCoreApplication::translate("MainWindow", "Start Solving", nullptr));
        editSolverProfile->setText(QCoreApplication::translate("MainWindow", "Edit", nullptr));
        ClearResults->setText(QCoreApplication::translate("MainWindow", "Clear", nullptr));
        Abort->setText(QCoreApplication::translate("MainWindow", "Abort", nullptr));
        label_32->setText(QCoreApplication::translate("MainWindow", "Trials:", nullptr));
        trials->setSuffix(QString());
        exportResultsTable->setText(QCoreApplication::translate("MainWindow", "Export Results", nullptr));
        status->setText(QCoreApplication::translate("MainWindow", "No Process Running", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
